==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/uk/admin/hardware/form.php <==
<?php

return array(
	'bulk_delete'		=> 'Confirm Bulk Delete Assets',
  'bulk_delete_help'	=> 'Review the assets for bulk deletion below. Once deleted, these assets can be restored, but they will no longer be associated with any users they are currently assigned to.',
  'bulk_delete_warn'	=> 'You are about to delete :asset_count assets.',
	'bulk_update'		=> 'Bulk Update Assets',
	'bulk_update_help'	=> 'This form allows you to update multiple assets at once. Only fill in the fields you need to change. Any fields left blank will remain unchanged. ',
	'bulk_update_warn'	=> 'You are about to edit the properties of :asset_count assets.',
    'checkedout_to'		=> 'Видано',
    'checkout_date'		=> 'Дата видачі',
    'checkin_date'		=> 'Дата повернення',
    'checkout_to'		=> 'Видати',
    'cost'				=> 'Вартість покупки',
    'create'			=> 'Створити актив',
    'date'				=> 'Дата покупки',
    'depreciation'	    => 'Depreciation',
    'depreciates_on'	=> 'Depreciates On',
    'default_location'	=> 'Default Location',
    'eol_date'			=> 'Дата EOL',
    'eol_rate'			=> 'EOL Rate',
    'expected_checkin'  => 'Очікувана дата повернення',
    'expires'			=> 'Термін закінчується',
    'fully_depreciated'	=> 'Fully Depreciated',
    'help_checkout'		=> 'If you wish to assign this asset immediately, select "Ready to Deploy" from the status list above. ',
    'mac_address'		=> 'MAC-адреса',
    'manufacturer'		=> 'Виробник',
    'model'				=> 'Модель',
    'months'			=> 'міс.',
    'name'				=> 'Назва активу',
    'notes'				=> 'Нотатки',
    'order'				=> 'Номер замовлення',
    'qr'				=> 'QR-код',
    'requestable'		=> 'Users may request this asset',
    'select_statustype'	=> 'Select Status Type',
    'serial'			=> 'Серійник',
    'status'			=> 'Статус',
    'tag'				=> 'Asset Tag',
    'update'			=> 'Оновити актив',
    'warranty'			=> 'Гарантія',
		'warranty_expires'		=> 'Warranty Expires',
    'years'				=> 'р.',
)
;

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/uk/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Confirm Bulk Delete Assets',
  'bulk_delete_help'	=> 'Review the assets for bulk deletion below. Once deleted, these assets can be restored, but they will no longer be associated with any users they are currently assigned to.',
  'bulk_delete_warn'	=> 'You are about to delete :asset_count assets.',
    'bulk_update'		=> 'Bulk Update Assets',
    'bulk_update_help'	=> 'This form allows you to update multiple assets at once. Only fill in the fields you need to change. Any fields left blank will remain unchanged. ',
    'bulk_update_warn'	=> 'You are about to edit the properties of :asset_count assets.',
    'checkedout_to'		=> 'Видано',
    'checkout_date'		=> 'Дата видачі',
    'checkin_date'		=> 'Дата повернення',
    'checkout_to'		=> 'Видати',
    'cost'				=> 'Вартість покупки',
    'create'			=> 'Створити актив',
    'date'				=> 'Дата покупки',
    'depreciation'	    => 'Depreciation',
    'depreciates_on'	=> 'Depreciates On',
    'default_location'	=> 'Default Location',
    'eol_date'			=> 'Дата EOL',
    'eol_rate'			=> 'EOL Rate',
    'expected_checkin'  => 'Очікувана дата повернення',
    'expires'			=> 'Термін закінчується',
    'fully_depreciated'	=> 'Fully Depreciated',
    'help_checkout'		=> 'If you wish to assign this asset immediately, select "Ready to Deploy" from the status list above. ',
    'mac_address'		=> 'MAC-адреса',
    'manufacturer'		=> 'Виробник',
    'model'				=> 'Модель',
    'months'			=> 'міс.',
    'name'				=> 'Назва активу',
    'notes'				=> 'Нотатки',
    'order'				=> 'Номер замовлення',
    'qr'				=> 'QR-код',
    'requestable'		=> 'Users may request this asset',
    'select_statustype'	=> 'Select Status Type',
    'serial'			=> 'Серійник',
    'status'			=> 'Статус',
    'tag'				=> 'Asset Tag',
    'update'			=> 'Оновити актив',
    'warranty'			=> 'Гарантія',
        'warranty_expires'		=> 'Warranty Expires',
    'years'				=> 'р.',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing...',
];
